@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 #
 # Copyright 2009,2010,2012 Free Software Foundation, Inc.
 #
@@ -20,15 +20,17 @@
 # Boston, MA 02110-1301, USA.
 #
 
-import optfir, math
+from __future__ import print_function
+from __future__ import division
+from __future__ import unicode_literals
 
-from gnuradio import gr, fft
-import filter_swig as filter
+import math
+
+from gnuradio import gr, fft, blocks
+
+from . import optfir
+from . import filter_swig as filter
 
-try:
-    from gnuradio import blocks
-except ImportError:
-    import blocks_swig as blocks
 
 class channelizer_ccf(gr.hier_block2):
     '''
@@ -71,7 +73,7 @@ class channelizer_ccf(gr.hier_block2):
                                               self._oversample_rate)
         self.connect(self, self.s2ss)
 
-        for i in xrange(self._nchans):
+        for i in range(self._nchans):
             self.connect((self.s2ss,i), (self.pfb,i))
             self.connect((self.pfb,i), (self,i))
 
@@ -147,9 +149,9 @@ class decimator_ccf(gr.hier_block2):
     '''
     def __init__(self, decim, taps=None, channel=0, atten=100,
                  use_fft_rotators=True, use_fft_filters=True):
-	gr.hier_block2.__init__(self, "pfb_decimator_ccf",
-				gr.io_signature(1, 1, gr.sizeof_gr_complex),
-				gr.io_signature(1, 1, gr.sizeof_gr_complex))
+        gr.hier_block2.__init__(self, "pfb_decimator_ccf",
+                                gr.io_signature(1, 1, gr.sizeof_gr_complex),
+                                gr.io_signature(1, 1, gr.sizeof_gr_complex))
 
         self._decim = decim
         self._channel = channel
@@ -181,7 +183,7 @@ class decimator_ccf(gr.hier_block2):
 
         self.connect(self, self.s2ss)
 
-        for i in xrange(self._decim):
+        for i in range(self._decim):
             self.connect((self.s2ss,i), (self.pfb,i))
 
         self.connect(self.pfb, self)
@@ -227,7 +229,7 @@ class arb_resampler_ccf(gr.hier_block2):
             if(self._rate < 1):
                 halfband = 0.5*self._rate
                 bw = percent*halfband
-                tb = (percent/2.0)*halfband
+                tb = (percent / 2.0)*halfband
                 ripple = 0.1
 
                 # As we drop the bw factor, the optfir filter has a harder time converging;
@@ -237,7 +239,7 @@ class arb_resampler_ccf(gr.hier_block2):
             else:
                 halfband = 0.5
                 bw = percent*halfband
-                tb = (percent/2.0)*halfband
+                tb = (percent / 2.0)*halfband
                 ripple = 0.1
 
                 made = False
@@ -255,7 +257,7 @@ class arb_resampler_ccf(gr.hier_block2):
                             raise RuntimeError("optfir could not generate an appropriate filter.")
 
         self.pfb = filter.pfb_arb_resampler_ccf(self._rate, self._taps, self._size)
-        #print "PFB has %d taps\n" % (len(self._taps),)
+        #print("PFB has %d taps\n" % (len(self._taps),))
 
         self.connect(self, self.pfb)
         self.connect(self.pfb, self)
@@ -301,7 +303,7 @@ class arb_resampler_fff(gr.hier_block2):
             if(self._rate < 1):
                 halfband = 0.5*self._rate
                 bw = percent*halfband
-                tb = (percent/2.0)*halfband
+                tb = (percent / 2.0)*halfband
                 ripple = 0.1
 
                 # As we drop the bw factor, the optfir filter has a harder time converging;
@@ -311,7 +313,7 @@ class arb_resampler_fff(gr.hier_block2):
             else:
                 halfband = 0.5
                 bw = percent*halfband
-                tb = (percent/2.0)*halfband
+                tb = (percent / 2.0)*halfband
                 ripple = 0.1
 
                 made = False
@@ -405,14 +407,14 @@ class channelizer_hier_ccf(gr.hier_block2):
     Make a Polyphase Filter channelizer (complex in, complex out, floating-point taps)
 
     Args:
-        n_chans - The number of channels to split into.
-        n_filterbanks - The number of filterbank blocks to use (default=2).
-        taps: The taps to use.  If this is `None` then taps are generated using optfir.low_pass.
-        outchans - Which channels to output streams for (a list of integers) (default is all channels).
-        atten: Stop band attenuation.
-        bw: The fraction of the channel you want to keep.
-        tb: Transition band with as fraction of channel width.
-        ripple: Pass band ripple in dB.
+    n_chans: The number of channels to split into.
+    n_filterbanks: The number of filterbank blocks to use (default=2).
+    taps: The taps to use.  If this is `None` then taps are generated using optfir.low_pass.
+    outchans: Which channels to output streams for (a list of integers) (default is all channels).
+    atten: Stop band attenuation.
+    bw: The fraction of the channel you want to keep.
+    tb: Transition band with as fraction of channel width.
+    ripple: Pass band ripple in dB.
     """
 
     def __init__(self, n_chans, n_filterbanks=1, taps=None, outchans=None,
@@ -420,7 +422,7 @@ class channelizer_hier_ccf(gr.hier_block2):
         if n_filterbanks > n_chans:
             n_filterbanks = n_chans
         if outchans is None:
-            outchans = range(n_chans)
+            outchans = list(range(n_chans))
         gr.hier_block2.__init__(
             self, "pfb_channelizer_hier_ccf",
             gr.io_signature(1, 1, gr.sizeof_gr_complex),
@@ -436,7 +438,7 @@ class channelizer_hier_ccf(gr.hier_block2):
         self.s2v = blocks.stream_to_vector(gr.sizeof_gr_complex, n_chans)
         # Create a mapping to separate out each filterbank (a group of channels to be processed together)
         # And a list of sets of taps for each filterbank.
-        low_cpp = int(n_chans/n_filterbanks)
+        low_cpp = int(n_chans / n_filterbanks)
         extra = n_chans - low_cpp*n_filterbanks
         cpps = [low_cpp+1]*extra + [low_cpp]*(n_filterbanks-extra)
         splitter_mapping = []
@@ -460,7 +462,7 @@ class channelizer_hier_ccf(gr.hier_block2):
         # Add the final FFT to the channelizer.
         self.fft = fft.fft_vcc(n_chans, forward=True, window=[1.0]*n_chans)
         # Select the desired channels
-        if outchans != range(n_chans):
+        if outchans != list(range(n_chans)):
             selector_mapping = [[(0, i) for i in outchans]]
             self.selector = blocks.vector_map(gr.sizeof_gr_complex, [n_chans], selector_mapping)
         # Convert stream of vectors to a normal stream.
@@ -469,7 +471,7 @@ class channelizer_hier_ccf(gr.hier_block2):
         for i in range(0, n_filterbanks):
             self.connect((self.splitter, i), self.fbs[i], (self.combiner, i))
         self.connect(self.combiner, self.fft)
-        if outchans != range(n_chans):
+        if outchans != list(range(n_chans)):
             self.connect(self.fft, self.selector, self.v2ss)
         else:
             self.connect(self.fft, self.v2ss)
